{% extends "base.html" %} {% block main %}

## Community

Get inspired and get involved.
Get in touch, exchange ideas, and ask questions in our Discord online chat.
Discuss
Inspire the community by viewing and adding work to our showcase.
Share
Found an issue? Got a request? Have suggestions? Make a ticket.
File
Help others by providing documentation and examples.
Assist
Fix bugs and implement new features for Sketchingpy as a developer.
Code
Project design goals, common practices, and coding conventions.
Read
{% endblock %}